# Math Practice

Maths practice are some simple exercises for kids to use 
to practice the material in the course
"Mastering the Fundamentals of Mathematics course
by Professor James A. Sellers."

These exercises are not endorsed in any way by "The Great Courses"
or "Professor James A. Sellers". They were created for my kids to
practice what they were learning from Professor Sellers excellent course.

## Subjects

Lesson 1 - Addition and Subtraction

Lesson 2 - Multiplication

Lesson 3 - Division

